"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  AuthenticationProvider: () => AuthenticationProvider_default,
  useAccount: () => useUserAccount_default,
  useAuthenticated: () => useAuthenticated_default,
  useAuthentication: () => useMsalAuthentication_default
});
module.exports = __toCommonJS(src_exports);

// src/AuthenticationProvider.tsx
var import_react5 = __toESM(require("react"));
var import_msal_browser3 = require("@azure/msal-browser");
var import_msal_react2 = require("@azure/msal-react");

// src/hooks/useConfiguration.ts
var import_react = require("react");

// src/helper/index.ts
var getEnvironmentValue = (key, isRequired = false) => {
  const envKey = process.env[`VITE_${key}`];
  if (envKey === void 0 || envKey === null && isRequired) {
    throw new Error(`VITE_${key} is not exists in the .env file`);
  }
  return envKey;
};
var Constants = {
  SPLIT_COMMA: ",",
  DEFAULT_TOKEN_INTERVAL: "3600000",
  DEFAULT_TOKEN_THRESHOLD: "300",
  DEFAULT_SCOPES: ["User.Read"],
  MIDDLEWARE_URL: "_MIDDLEWARE_URL",
  MIDDLEWARE_KEY: "_MIDDLEWARE_KEY",
  CLIENT_ID: "MSAL_CLIENT_ID",
  AUTHORITY: "MSAL_AUTHORITY",
  REDIRECT_URL: "MSAL_REDIRECT_URL",
  LOGOUT_REDIRECT_URL: "MSAL_LOGOUT_REDIRECT_URL",
  SCOPES: "MSAL_SCOPES",
  CACHE_LOCATION: "MSAL_CACHE_LOCATION",
  TOKEN_INTERVAL: "MSAL_TOKEN_INTERVAL",
  TOKEN_REFRESH_THRESHOLD: "MSAL_TOKEN_REFRESH_THRESHOLD"
};

// src/AuthenticationInstance.ts
var import_msal_browser = require("@azure/msal-browser");
var AuthenticationInstance = class {
  /**
   * PublicClientApplication property
   */
  PublicClientApplication;
  /**
   * Overload constructor function
   */
  constructor(instance) {
    if (instance === void 0 || instance === null) {
      instance = {
        auth: {
          clientId: getEnvironmentValue(Constants.CLIENT_ID, true),
          authority: getEnvironmentValue(Constants.AUTHORITY, true),
          redirectUri: getEnvironmentValue(Constants.REDIRECT_URL, true),
          postLogoutRedirectUri: getEnvironmentValue(Constants.LOGOUT_REDIRECT_URL)
        },
        cache: {
          cacheLocation: getEnvironmentValue(Constants.CACHE_LOCATION) || import_msal_browser.BrowserCacheLocation.LocalStorage,
          storeAuthStateInCookie: true
        },
        system: {
          tokenRenewalOffsetSeconds: parseInt(getEnvironmentValue(Constants.TOKEN_REFRESH_THRESHOLD) || Constants.DEFAULT_TOKEN_THRESHOLD)
        }
      };
    }
    this.PublicClientApplication = new import_msal_browser.PublicClientApplication(instance);
  }
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [instance, setInstance] = (0, import_react.useState)();
  const [options, setOptions] = (0, import_react.useState)();
  (0, import_react.useEffect)(() => {
    setConfiguration(authConfig);
  }, [authConfig]);
  const setConfiguration = (authConfig2) => {
    const msalInstance = new AuthenticationInstance(authConfig2?.instance);
    let option;
    if (authConfig2 != null && authConfig2.option) {
      option = authConfig2.option;
    } else {
      option = {
        scopes: [getEnvironmentValue(Constants.SCOPES, true)],
        tokenInterval: parseInt(getEnvironmentValue(Constants.TOKEN_INTERVAL) || Constants.DEFAULT_TOKEN_INTERVAL),
        tokenThreshold: parseInt(getEnvironmentValue(Constants.TOKEN_REFRESH_THRESHOLD) || Constants.DEFAULT_TOKEN_THRESHOLD)
      };
    }
    setOptions(option);
    setInstance(msalInstance.PublicClientApplication);
  };
  return { config: instance, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
var import_react4 = __toESM(require("react"));

// src/hooks/useUserAccount.ts
var import_react3 = require("react");
var import_msal_react = require("@azure/msal-react");
var import_msal_browser2 = require("@azure/msal-browser");
var import_jwt_decode = require("jwt-decode");
var import_unw_react_framework_user = require("unw.react.framework.user.identity");

// src/AuthenticationContext.ts
var import_react2 = require("react");
var AuthenticationContext = (0, import_react2.createContext)(null);

// src/hooks/useUserAccount.ts
var useUserAccount = () => {
  const { instance, accounts } = (0, import_msal_react.useMsal)();
  const authentication = (0, import_react3.useContext)(AuthenticationContext);
  const { setUserToken, getTokenInfo } = (0, import_unw_react_framework_user.useUserTokenService)();
  const { getAPIServiceTokenInfo, setAPIServiceToken } = (0, import_unw_react_framework_user.useAPITokenService)();
  const { setUserClaims } = (0, import_unw_react_framework_user.useUserClaimService)();
  const { setUserInfo } = (0, import_unw_react_framework_user.useUserService)();
  const getUserToken = async () => {
    const token = getTokenInfo();
    if (token && !isTokenExpired(0, token)) {
      return token;
    }
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
    }
    return accountInfo?.accessToken;
  };
  const getServiceApiAccessToken = async (key) => {
    const apiServiceToken = getAPIServiceTokenInfo(key);
    if (apiServiceToken && apiServiceToken != null) {
      if (!isTokenExpired(0, apiServiceToken.refreshToken)) {
        return apiServiceToken.refreshToken;
      } else if (!isTokenExpired(0, apiServiceToken.accessToken)) {
        return apiServiceToken.accessToken;
      }
    }
    const tokenInfo = await getApiTokenInfo(key);
    if (tokenInfo) {
      const sharePointToken = [
        {
          tokenId: key,
          refreshToken: tokenInfo.access_token,
          accessToken: tokenInfo.access_token,
          tokenExpirationDate: tokenInfo.expires_on.toLocaleString()
        }
      ];
      setAPIServiceToken(sharePointToken);
      return tokenInfo.access_token;
    }
    return null;
  };
  const getApiTokenInfo = async (key) => {
    const envKey = key.toUpperCase();
    const apiAccessUrl = getEnvironmentValue(envKey + Constants.MIDDLEWARE_URL);
    const middlewareKey = getEnvironmentValue(envKey + Constants.MIDDLEWARE_KEY);
    const response = await fetch(apiAccessUrl, {
      method: "GET",
      headers: {
        "X-Middleware-Key": middlewareKey
      }
    });
    return response.json();
  };
  const setClaims = async (userClaims) => {
    if (userClaims && userClaims.length > 0) {
      setUserClaims(userClaims);
    }
  };
  const getAcquireTokenSilent = async (scopes) => {
    const authRequest = { account: accounts[0], scopes: Constants.DEFAULT_SCOPES };
    if (scopes != null && scopes.length > 0) {
      authRequest.scopes = scopes;
    }
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof import_msal_browser2.InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
      setAccessTokenToStore(accountInfo);
    }
  };
  const setUserTokenToStore = (accountInfo) => {
    if (accountInfo) {
      const userToken = {
        tokenId: accountInfo.account?.localAccountId,
        idToken: accountInfo.account?.idToken,
        accessToken: accountInfo.accessToken,
        refreshToken: accountInfo.accessToken,
        tokenExpirationDate: accountInfo.expiresOn.toLocaleString()
      };
      setUserToken(userToken);
    }
  };
  const setAccessTokenToStore = (accountInfo) => {
    const accessToken = accountInfo.accessToken;
    if (accessToken) {
      const decodeToken = (0, import_jwt_decode.jwtDecode)(accessToken);
      if (decodeToken) {
        const user = {
          name: decodeToken.name,
          firstname: decodeToken.given_name,
          lastName: decodeToken.family_name,
          email: accountInfo.username,
          upn: decodeToken.upn,
          guid: decodeToken.oid
        };
        setUserInfo(user);
      }
    }
  };
  const setAcquireTokenToStore = async () => {
    const scopes = authentication?.option?.scopes;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      setAccountInfoToStore(accountInfo);
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
    await setAcquireTokenToStore();
    setRefreshTokenInterval();
  };
  const setRefreshTokenInterval = () => {
    const option = authentication?.option;
    if (option) {
      const threshold = option.tokenThreshold;
      const interval = option.tokenInterval;
      setInterval(() => {
        const token = getTokenInfo();
        if (token === void 0 || isTokenExpired(threshold, token)) {
          setAcquireTokenToStore();
        }
      }, interval);
    }
  };
  const isTokenExpired = (tokenThreshold, token) => {
    let isExpired = false;
    if (token && token != null) {
      const decodeToken = (0, import_jwt_decode.jwtDecode)(token);
      if (decodeToken.exp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = decodeToken.exp - currentTime;
        isExpired = timeUntilExpiry <= (tokenThreshold ?? 0);
      }
    }
    return isExpired;
  };
  return { getUserToken, getServiceApiAccessToken, setUserActiveAccount, setClaims };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children }) => {
  const { setUserActiveAccount } = useUserAccount_default();
  (0, import_react4.useEffect)(() => {
    setUserActiveAccount();
  }, []);
  return /* @__PURE__ */ import_react4.default.createElement(import_react4.default.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ import_react5.default.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ import_react5.default.createElement(import_react5.default.Fragment, null, /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.AuthenticatedTemplate, null, /* @__PURE__ */ import_react5.default.createElement(AuthenticationSuccess_default, null, children))) : /* @__PURE__ */ import_react5.default.createElement(import_react5.default.Fragment, null, /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: import_msal_browser3.InteractionType.Redirect }, /* @__PURE__ */ import_react5.default.createElement(AuthenticationSuccess_default, null, children))))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
var import_msal_react3 = require("@azure/msal-react");
var useMsalAuthentication = () => {
  const { instance } = (0, import_msal_react3.useMsal)();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
var import_msal_react4 = require("@azure/msal-react");
var useAuthenticated = () => {
  const isAuthenticated = (0, import_msal_react4.useIsAuthenticated)();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  AuthenticationProvider,
  useAccount,
  useAuthenticated,
  useAuthentication
});
